fileName = 'VampNoise';
checkCircuit(fileName);
htmlPage('Circuit data');
head2html(['Circuit diagram: ', fileName]);
img2html([fileName, '.svg'], 800);
netlist2html(fileName);
%%
gainType('vi');
dataType('noise');
%
% Define souce, detector, source resistance and voltage gain factor
source('V1');
detector('V_out');
%
htmlPage('Symbolic noise analysis');
simType('symbolic');
noiseResultSym = execute();
noise2html(noiseResultSym);
%
htmlPage('Numeric noise analysis');
simType('numeric');
noiseResultNum = execute();
noise2html(noiseResultNum);
%
%%
% Let us find show-stopper values for R_a, S_v, and S_i for the case in
% which the noise factor NF=2 (3dB).
%
% Determine the noise factor NF: (this procedure works with
% frequency-independent noise spectra only)
%
syms('R_a', 'S_v', 'S_i', 'NF', 'R_a_max', 'S_i_max', 'S_v_max');
htmlPage('Show-stopper values');
%
text2html(['Let us find show-stopper values for $R_a$, $S_v$, and ' ...
    '$S_i$ for the case in which the noise factor $NF$ equals 2 (3dB).']);
head2html('Noise factor NF');
text2html('The noise factor NF [-] is obtained as:');
NFact = simplify(getInoise(noiseResultNum)/getInoise(noiseResultNum, 'V1'));
eqn2html(NF, NFact);
%
% Show stopper (= maximum) value $R_{amax}$ for R_a with S_i=0 and S_v=0
Ra_max = vpa(solve(subs(NFact-2, [S_v, S_i], [0, 0]), R_a), 3);
head2html('Show-stopper value $R_a$');
text2html(['The show stopper value $R_{amax}$ for $R_a$ with $NF=2$, ',...
    '$S_v=0$ and $S_i=0$ is obained as:']);
eqn2html(R_a_max, Ra_max);
%
% Show stopper (= maximum) $S_{v,max}$ for S_v as a function of R_a and S_i=0
Sv_max = vpa(solve(subs(NFact-2, S_i, 0), S_v), 3);
head2html('Show-stopper value $S_v$');
text2html(['The show stopper value for $S_v$ with $NF=2$ and $S_i=0$ ',...
    'can be obained a function of $R_a$ (setting $R_a$ to zero would ' ...
    'be meaningless):']);
eqn2html(S_v_max, Sv_max);
%
% Show stopper (= maximum) $S_{i,max}$ for S_i as a function of R_a and S_i=0
Si_max = vpa(solve(subs(NFact-2, S_v, 0), S_i), 3);
head2html('Show-stopper value $S_i$');
text2html(['The show stopper value for $S_i$ with $NF=2$ and $S_v=0$ ',...
    'can be obained a function of $R_a$: (setting $R_a$ to zero would ' ...
    'be meaningless):']);
eqn2html(S_i_max, Si_max);
%
script2html('VampNoise');
stophtml();